@@ -11,7 +11,7 @@ our (@EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 BEGIN
 {
 	$Number::Natural::SetTheory::AUTHORITY = 'cpan:TOBYINK';
-	$Number::Natural::SetTheory::VERSION   = '0.002';
+	$Number::Natural::SetTheory::VERSION   = '0.003';
 	
 	@EXPORT    = qw/ /;
 	@EXPORT_OK = qw/ set_is_number set_to_number number_to_set set_to_string /;
@@ -19,7 +19,7 @@ BEGIN
 	$EXPORT_TAGS{'default'} = $EXPORT_TAGS{'standard'} = \@EXPORT;
 }
 
-use parent qw/Exporter/;
+use base qw/Exporter/;
 
 sub set_is_number
 {
@@ -218,7 +218,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2011 by Toby Inkster.
+This software is copyright (c) 2011-2012 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
